==> digikam-3.0.0-beta2.tar.bz2: digikam-3.0.0-beta2/extra/kipi-plugins/ipodexport/kipiplugin_ipodexport.desktop.cmake <==
[Desktop Entry]
Name=iPodExport
Name[ast]=iPodExport
Name[bg]=Изнасяне към iPod
Name[bs]=iPod Izvoz
Name[ca]=iPodExport
Name[ca@valencia]=iPodExport
Name[cs]=iPodExport
Name[da]=iPodExport
Name[de]=iPodExport
Name[el]=Εξαγωγή iPod
Name[en_GB]=iPodExport
Name[es]=iPodExport
Name[et]=iPodi eksport
Name[eu]=iPod esportatzea
Name[fr]=Export IPod
Name[ga]=iPodExport
Name[gl]=iPodExport
Name[he]=יצוא ל-iPod
Name[hne]=आई-पाड-एक्सपोर्ट
Name[hu]=iPodExport
Name[is]=iPodÚtflutningur
Name[it]=Esportazione a iPod
Name[ja]=iPodExport
Name[km]=iPodExport
Name[lv]=iPod eksports
Name[nb]=iPod-eksport
Name[nds]=iPott-Export
Name[nl]=iPodExport
Name[pa]=iPodExport
Name[pl]=EksportDoiPoda
Name[pt]=iPodExport
Name[pt_BR]=Exportar para o iPod
Name[ro]=Export iPod
Name[ru]=Экспорт в iPod
Name[sk]=iPod export
Name[sl]=iPodExport
Name[sq]=iPodExport
Name[sv]=Export till iPod
Name[th]=ส่งออกไปยังไอพ็อด
Name[tr]=iPod'a Aktarıcı
Name[uk]=iPodExport
Name[x-test]=xxiPodExportxx
Name[zh_CN]=iPod 导出
Name[zh_TW]=iPod 匯出
Comment=A tool to export pictures to an Ipod device
Comment[ast]=Una ferramienta pa esportar imáxenes a un preséu Ipod
Comment[bg]=Инструмент за изнасяне на снимки към устройство ipod
Comment[bs]=Alat za izvoz slika na Ipod uređaj
Comment[ca]=Una eina per exportar fotografies a un dispositiu Ipod
Comment[ca@valencia]=Una eina per exportar fotografies a un dispositiu Ipod
Comment[cs]=Nástroj pro export obrázků na iPod
Comment[da]=Et værktøj til at eksportere billeder til en iPod-enhed
Comment[de]=Ein Werkzeug, um Bilder zu einem iPod zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια συσκευή Ipod
Comment[en_GB]=A tool to export pictures to an Ipod device
Comment[es]=Una herramienta para exportar imágenes a un dispositivo Ipod
Comment[et]=Tööriist piltide eksportimiseks iPodi seadmele
Comment[eu]=Ipod gailu batera irudiak esportatzeko tresna
Comment[fi]=Kuvien kopiointi iPodille
Comment[fr]=Outil pour l'exportation d'image vers un IPod
Comment[gl]=Unha ferramenta para exportar imaxes a un dispositivo Ipod
Comment[he]=כלי ליצוא תמונות להתקן iPod
Comment[hne]=आई-पाड उपकरन मं फोटू ल निर्यात करे के एक औजार
Comment[hu]=Egy eszköz képek exportálásához Ipod eszközre
Comment[is]=Tól til að flytja myndir yfir í iPod tæki
Comment[it]=Uno strumento per esportare immagini a un dispositivo iPod
Comment[ja]=画像を iPod デバイスにエクスポートするツール
Comment[km]=ឧបករណ៍​​ត្រូវ​នាំរូបភាព​ចេញ​ទៅ​កាន់​ឧបករណ៍ Ipod
Comment[lv]=Rīks attēlu eksportēšanai uz Ipod
Comment[nb]=Et verktøy for å eksportere bilder til en iPod-enhet
Comment[nds]=En Warktüüch, mit dat sik Biller na en iPott exporteren laat
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Ipod te exporteren
Comment[pl]=Narzędzie do eksportowania zdjęć do urządzenia Ipod
Comment[pt]=Uma ferramenta para exportar imagens para um dispositivo iPod
Comment[pt_BR]=Uma ferramenta para exportar imagens para um dispositivo iPod
Comment[ro]=O unealtă de exportat imagini către un dispozitiv iPod
Comment[ru]=Инструмент для экспорта изображений в iPod
Comment[sk]=Nástroj na export obrázkov do iPod zariadenia
Comment[sl]=Orodje za izvoz slik na napravo iPod 
Comment[sq]=Një mjet për të eksportuar fotografi në një pajisje Ipod
Comment[sv]=Ett verktyg för att exportera bilder till en iPod
Comment[th]=เครื่องมือในการส่งออกภาพถ่ายต่าง ๆ ไปยังอุปกรณ์ไอพ็อด
Comment[tr]=Resimleri bir Ipod aygıtına aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень на пристрій Ipod
Comment[x-test]=xxA tool to export pictures to an Ipod devicexx
Comment[zh_CN]=一个将图片导出到 Ipod 设备的工具
Comment[zh_TW]=匯出影像到 iPod 裝置的工具
Type=Service
Icon=multimedia-player-apple-ipod
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_ipodexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Seb Ruiz, me@sebruiz.net

==> digikam-3.2.0-beta2.tar.bz2: digikam-3.2.0-beta2/extra/kipi-plugins/ipodexport/kipiplugin_ipodexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=iPodExport
Name=iPodExport
Name[ast]=iPodExport
Name[bg]=Изнасяне към iPod
Name[bs]=iPod Izvoz
Name[ca]=Exportador a iPod
Name[ca@valencia]=iPodExport
Name[cs]=iPodExport
Name[da]=iPodExport
Name[de]=iPodExport
Name[el]=Εξαγωγή iPod
Name[en_GB]=iPodExport
Name[es]=iPodExport
Name[et]=iPodi eksport
Name[eu]=iPod esportatzea
Name[fr]=Export IPod
Name[ga]=iPodExport
Name[gl]=iPodExport
Name[he]=יצוא ל-iPod
Name[hne]=आई-पाड-एक्सपोर्ट
Name[hu]=iPodExport
Name[is]=iPodÚtflutningur
Name[it]=Esportazione a iPod
Name[ja]=iPodExport
Name[km]=iPodExport
Name[lv]=iPod eksports
Name[nb]=iPod-eksport
Name[nds]=iPott-Export
Name[nl]=iPodExport
Name[pa]=iPodExport
Name[pl]=EksportDoiPoda
Name[pt]=iPodExport
Name[pt_BR]=Exportar para o iPod
Name[ro]=Export iPod
Name[ru]=Экспорт в iPod
Name[sk]=iPod export
Name[sl]=iPodExport
Name[sq]=iPodExport
Name[sv]=Export till iPod
Name[th]=ส่งออกไปยังไอพ็อด
Name[tr]=iPod'a Aktarıcı
Name[uk]=iPodExport
Name[x-test]=xxiPodExportxx
Name[zh_CN]=iPod 导出
Name[zh_TW]=iPod 匯出
Comment=A tool to export pictures to an Ipod device
Comment[ast]=Una ferramienta pa esportar imáxenes a un preséu Ipod
Comment[bg]=Инструмент за изнасяне на снимки към устройство ipod
Comment[bs]=Alat za izvoz slika na Ipod uređaj
Comment[ca]=Una eina per exportar fotografies a un dispositiu Ipod
Comment[ca@valencia]=Una eina per exportar fotografies a un dispositiu Ipod
Comment[cs]=Nástroj pro export obrázků na iPod
Comment[da]=Et værktøj til at eksportere billeder til en iPod-enhed
Comment[de]=Ein Werkzeug, um Bilder zu einem iPod zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια συσκευή Ipod
Comment[en_GB]=A tool to export pictures to an Ipod device
Comment[es]=Una herramienta para exportar imágenes a un dispositivo Ipod
Comment[et]=Tööriist piltide eksportimiseks iPodi seadmele
Comment[eu]=Ipod gailu batera irudiak esportatzeko tresna
Comment[fi]=Kuvien kopiointi iPodille
Comment[fr]=Outil pour l'exportation d'image vers un IPod
Comment[gl]=Unha ferramenta para exportar imaxes a un dispositivo Ipod
Comment[he]=כלי ליצוא תמונות להתקן iPod
Comment[hne]=आई-पाड उपकरन मं फोटू ल निर्यात करे के एक औजार
Comment[hu]=Egy eszköz képek exportálásához Ipod eszközre
Comment[is]=Tól til að flytja myndir yfir í iPod tæki
Comment[it]=Uno strumento per esportare immagini a un dispositivo iPod
Comment[ja]=画像を iPod デバイスにエクスポートするツール
Comment[km]=ឧបករណ៍​​ត្រូវ​នាំរូបភាព​ចេញ​ទៅ​កាន់​ឧបករណ៍ Ipod
Comment[lv]=Rīks attēlu eksportēšanai uz Ipod
Comment[nb]=Et verktøy for å eksportere bilder til en iPod-enhet
Comment[nds]=En Warktüüch, mit dat sik Biller na en iPott exporteren laat
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Ipod te exporteren
Comment[pl]=Narzędzie do eksportowania zdjęć do urządzenia Ipod
Comment[pt]=Uma ferramenta para exportar imagens para um dispositivo iPod
Comment[pt_BR]=Uma ferramenta para exportar imagens para um dispositivo iPod
Comment[ro]=O unealtă de exportat imagini către un dispozitiv iPod
Comment[ru]=Инструмент для экспорта изображений в iPod
Comment[sk]=Nástroj na export obrázkov do iPod zariadenia
Comment[sl]=Orodje za izvoz slik na iPod 
Comment[sq]=Një mjet për të eksportuar fotografi në një pajisje Ipod
Comment[sv]=Ett verktyg för att exportera bilder till en iPod
Comment[th]=เครื่องมือในการส่งออกภาพถ่ายต่าง ๆ ไปยังอุปกรณ์ไอพ็อด
Comment[tr]=Resimleri bir Ipod aygıtına aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень на пристрій Ipod
Comment[x-test]=xxA tool to export pictures to an Ipod devicexx
Comment[zh_CN]=一个将图片导出到 Ipod 设备的工具
Comment[zh_TW]=匯出影像到 iPod 裝置的工具
Type=Service
Icon=multimedia-player-apple-ipod
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_ipodexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Seb Ruiz, me@sebruiz.net
